import React, { Fragment } from 'react'
import { isEmpty } from 'lodash'
import styled from 'styled-components'
import {
  Text,
  RemoteOpener,
  ManuscriptHeader,
  ManuscriptAssignHE,
  ManuscriptMetadata,
  ManuscriptDetailsTop,
} from 'pubsweet-component-faraday-ui'

const ManuscriptLayout = ({
  history,
  assignHE,
  revokeHE,
  currentUser,
  getSignedUrl,
  editorInChief,
  handlingEditors,
  hasResponseToReviewers,
  editorialRecommendations,
  journal = {},
  collection = {},
  fragment = {},
  permissions,
  isFetching,
}) => (
  <Root>
    {!isEmpty(collection) && !isEmpty(fragment) ? (
      <RemoteOpener>
        {(expanded, toggle) => (
          <Fragment>
            <ManuscriptDetailsTop
              collection={collection}
              currentUser={currentUser}
              fragment={fragment}
              getSignedUrl={getSignedUrl}
              history={history}
              {...permissions}
            />

            <ManuscriptHeader
              collection={collection}
              editorInChief={editorInChief}
              fragment={fragment}
              handlingEditors={handlingEditors}
              inviteHE={toggle}
              isFetching={isFetching.editorsFetching}
              journal={journal}
              resendInvitation={assignHE}
              revokeInvitation={revokeHE}
            />

            <ManuscriptMetadata
              currentUser={currentUser}
              fragment={fragment}
              getSignedUrl={getSignedUrl}
            />

            <ManuscriptAssignHE
              assignHE={assignHE}
              currentUser={currentUser}
              expanded={expanded}
              handlingEditors={handlingEditors}
              isFetching={isFetching.editorsFetching}
              toggle={toggle}
            />
          </Fragment>
        )}
      </RemoteOpener>
    ) : (
      <Text>Loading...</Text>
    )}
  </Root>
)

export default ManuscriptLayout

// #region styles
const Root = styled.div`
  overflow-y: auto;
  min-height: 50vh;
`
// #endregion
